#!/bin/bash

pwre_help()
{
  cat <<EOF
pwre_configure.h

Arguments

--help           Display help.

--version        State fix version of loadfiles, eg

                 > pwre configure --version "29-MAY-2011 16:00:00"

--reset-version  Reset previous version

--updatedir      Update makefile directories

EOF
}

pwre_config_init()
{
    d=`eval date +\"%F %X\"`
    cat > $cfile <<EOF
#!/bin/bash
#
# pwre configuration file
#
# Generated by pwre_configure $d
# Do not edit this file
#
EOF
}

pwre_config_check_include()
{
    let i=0
    let found=0
    let incfound=0
    IFS=:
    for file in $4
    do
      if test -e $file; then
	echo "...Checking   Yes   $1"
	echo "export PWRE_CONF_$2=1" >> $cfile

	if test $3 == "1"; then
	  conf_cc_define=$conf_cc_define" -DPWRE_CONF_$2=1"
	fi

 	incdir=${file%/*}
	if test $incdir == "/usr/include"; then
          incfound=1
        else
	  while [ $i -lt $inc_cnt ]; do
            if test ${inc_array[$i]} == $incdir; then
              incfound=1
            fi
	    i=$((i+1))
          done
	fi

	if test $incfound -eq 0; then
	  inc_array[$inc_cnt]=$incdir
          inc_cnt=$((inc_cnt+1))
        fi

        found=1
        break
      fi
    done

    if test $found -eq 0; then
	echo "...Checking   No    $1"
    fi
}
#
# Search for archive and insert in list
#
# Arguments
# 1: archive name
# 2: define name (PWRE_CONF_$2 will be defined)
# 3: special archives for gtk and motif (lib, gtk, motif) 
# 4: variable to insert archive in (rt, wb, gtk, motif)
# 5: if 1, add -DPWRE_CONF_$2 to cc command.
# 6: search list for archive.
# Examples
#  pwre_config_check_lib libm LIBM lib lib 0 /usr/lib/libm.so:/usr/lib/libm.a
#  pwre_config_check_lib gtk  GTK  gtk gtk 0 /usr/lib/libgtk-x11-2.0.so
#
pwre_config_check_lib()
{
    let i=0
    let found=0
    let libfound=0
    IFS=:
    for file in $6
    do

      if test -e $file; then
	echo "...Checking   Yes   $1"
	echo "export PWRE_CONF_$2=1" >> $cfile

	if test $5 == "1"; then
	  conf_cc_define=$conf_cc_define" -DPWRE_CONF_$2=1"
	fi

	if test $3 == "lib"; then
	  libdir=${file%/*}
	  if test $libdir == "/usr/lib"; then
            libfound=1
          else
	    while [ $i -lt $lib_cnt ]; do
	      if test ${lib_array[$i]} == $libdir; then
                libfound=1
	      fi
	      i=$((i+1))
            done
	  fi

	  if test $libfound -eq 0; then
	    lib_array[$lib_cnt]=$libdir
            lib_cnt=$((lib_cnt+1))
          fi

	  lib=${file##/*/lib}
          if test $4 == "gtk"; then
	    conf_libgtk=$conf_libgtk" -l${lib%.*}"
          elif test $4 == "motif"; then
	    conf_libmotif=$conf_libmotif" -l${lib%.*}"
          elif test $4 == "wb"; then
	    conf_libwb=$conf_libwb" -l${lib%.*}"
          elif test $4 == "mq"; then
	    conf_libmq=$conf_libmq" -l${lib%.*}"
          elif test $4 == "wmq"; then
	    conf_libwmq=$conf_libwmq" -l${lib%.*}"
          elif test $4 == "libusb"; then
	    conf_lib=$conf_lib" -lusb-1.0"
          else
	    conf_lib=$conf_lib" -l${lib%%.*}"
          fi
	elif test $3 == "gtk"; then
	  conf_libgtk=$conf_libgtk" \\\`pkg-config --libs gtk+-2.0\\\`"
	  conf_incdirgtk=$conf_incdirgtk" \\\`pkg-config --cflags gtk+-2.0\\\`"
	elif test $3 == "motif"; then
	  conf_libmotif=$conf_libmotif" -lImlib -lMrm -lXm -lXpm -lXt -lX11 -lXext -lXp -lSM -lICE"
	else
           echo "Unknown type"
	fi
	
        found=1
        break
      fi
    done

    if test $found -eq 0; then
	echo "...Checking   No    $1"
	echo "export PWRE_CONF_$2=0" >> $cfile
    fi
}

pwre_create_blddir()
{
  if test ! -e $pwre_croot/src/tools/bld/src/$pwre_os; then
    cp -r $pwre_croot/src/tools/bld/src/os_templ $pwre_croot/src/tools/bld/src/$pwre_os
    mv $pwre_croot/src/tools/bld/src/$pwre_os/hw_templ $pwre_croot/src/tools/bld/src/$pwre_os/$pwre_hw
  elif test ! -e $pwre_croot/src/tools/bld/src/$pwre_os/$pwre_hw; then
    cp -r $pwre_croot/src/tools/bld/src/os_templ/hw_templ $pwre_croot/src/tools/bld/src/$pwre_os/$pwre_hw
  fi
}

pwre_create_makedir()
{
  dirlist=`eval find $pwre_croot -name "os_templ"`
  for dir in $dirlist; do
    newdir=${dir%/*}/$pwre_os
    if test ! -e $newdir; then 
      newdir=${dir%/*}/.$pwre_os
      if test ! -e $newdir; then 
        echo "Creating $newdir"
        cp -pr $dir $newdir
        if test -e $newdir/hw_templ; then
          mv $newdir/hw_templ $newdir/.$pwre_hw
        fi
    
      else
        # os directory .os_ already exist
        # Copy new and modified files
        filelist=`eval ls $dir/`
        for file in $filelist; do
          if test ! -d $dir/$file; then 
            cp -p $dir/$file $newdir/
          fi
        done
        if test -e $newdir/.$pwre_hw; then
          cp -p $dir/hw_templ/* $newdir/.$pwre_hw/
        elif test -e $dir/hw_templ; then
          # Create hw dir
          echo "Creating $newdir/$pwre_hw"
          cp -pr $dir/hw_templ $newdir/.$pwre_hw
        fi
      fi
    else
      ## os director os_ exist
      if test ! -e $newdir/$pwre_hw; then
        if test -e $newdir/.$pwre_hw; then
          cp -p $dir/hw_templ/* $newdir/.$pwre_hw/
        elif test -e $dir/hw_templ; then
          # Create hw dir
          echo "Creating $newdir/.$pwre_hw"
          cp -pr $dir/hw_templ $newdir/.$pwre_hw
        fi
      fi
    fi
  done

  rm $pwre_croot/remote/exe/rs_remote_alcm/src/.${pwre_os}/.${pwre_hw}/makefile
}


#pwre_os="os_linux"
#pwre_hw="hw_x86"

cfile="$pwre_broot/pwre_${pwre_hw:3}_${pwre_os:3}.cnf"
dos=`eval echo ${pwre_os} | tr [:lower:] [:upper:]`
dhw=`eval echo ${pwre_hw} | tr [:lower:] [:upper:]`
conf_cc_define="-D$dos=1 -DOS_POSIX -D$dhw=1 -DOS=${pwre_os:3} -DHW=${pwre_hw:3} -D_${dos:3}"
conf_lib=""
conf_libwb=""
conf_libmq=""
conf_libwmq=""
conf_libgtk="" 
conf_libmotif="" 
conf_libdir=""
conf_incdirgtk=""
let inc_cnt=0
let lib_cnt=0
let i=0
let updatedir=0
hwpl=`eval uname -i`

# Bash
if [ "$SHELL" != "/bin/bash" ] && [ "$SHELL" != "/usr/local/bin/bash" ]; then
    echo "Config error: Default shell has to be bash"
    exit
fi

echo "...Checking         /bin/bash"
if test ! -e /bin/bash; then
  if test -e /usr/local/bin/bash; then
      echo "Config error: /bin/bash not found"
      echo "  Create link /bin/bash to /usr/local/bin/bash (ln -s /usr/local/bin/bash /bin/bash)"
  else
      echo "Config error: /bin/bash not found"
  fi
  exit
fi

if test "$pwre_broot" == ""; then
  echo "Config error: pwre not initialized"
  exit
fi

if test ! -w $pwre_broot; then
  echo "Config error: pwre build root doesn't exist or is not writable"
  exit
fi

if test ! -e $pwre_croot; then
  echo "Config error: pwre source root doesn't exist"
  exit
fi

# Options
if [ "$1" = "--help" ]; then
  pwre_help
  exit
elif [ "$1" = "--version" ] && [ "$2" != "" ] && [ "$3" != "" ]; then
  buildversion=$2" "$3
elif [ "$1" = "--reset-version" ]; then
  buildversion=""
elif [ "$1" = "--updatedir" ]; then
  updatedir=1
elif [ "$1" != "" ]; then
  echo "Unknown option \"$1\""
  exit
else
  # Catch current version
  if [ -e $cfile ]; then
    ver=`eval cat $cfile | grep "\bexport PWRE_CONF_BUILDVERSION"`
    ver=${ver#*=\"}
    ver=${ver%\"}
    buildversion=$ver
  fi
fi


pwre_create_blddir
if [ $updatedir -eq 1 ]; then
  pwre_create_makedir
fi

pwre_config_init

if [ "$buildversion" != "" ]; then
  echo "export PWRE_CONF_BUILDVERSION=\"$buildversion\"" >> $cfile
else
  echo "export PWRE_CONF_BUILDVERSION=\"0\"" >> $cfile
fi
      
if test $pwre_hw == "hw_arm"; then

  pwre_config_check_include jni   JNI   1 $jdk/include/jni.h
  pwre_config_check_include jni   JNI   0 $jdk/include/cygwin/jni_md.h

  rm $pwre_sroot/tools/exe/tools_cmsg2c/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/tools/exe/tools_msg2cmsg/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/tools/exe/tools_pdrgen/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/tools/exe/tools_javac/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/exe/co_convert/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/exe/wb_rtt/src/.os_linux/.hw_arm/makefile
  rm $pwre_sroot/exe/rt_elog/src/.os_linux/.hw_arm/makefile

  let i=0
  while [ $i -lt $inc_cnt ]; do
      conf_incdir=$conf_incdir" -I${inc_array[$i]}"
      i=$((i+1))
  done

  echo "export pwre_conf_cc_define=\"$conf_cc_define\"" >> $cfile
  echo "export pwre_conf_libpwrco=\"-lpwr_co\"" >> $cfile
  echo "export pwre_conf_libpwrrt=\"-lpwr_rt -lpwr_statussrv -lpwr_co -lpwr_msg_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrdtt=\"-lpwr_dtt\"" >> $cfile
  echo "export pwre_conf_libpwrotherio=\"-lpwr_usbio_dummy -lpwr_usb_dummy -lpwr_cifx_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrprofibus=\"-lpwr_pnak_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrxtt=\"-lpwr_xtt -lpwr_ge -lpwr_cow -lpwr_flow -lpwr_glow\"" >> $cfile
  echo "export pwre_conf_libpwrxttgtk=\" -lpwr_xtt_gtk -lpwr_ge_gtk -lpwr_cow_gtk -lpwr_flow_gtk -lpwr_glow_gtk\"" >> $cfile
  echo "export pwre_conf_libpwrxttmotif=\" -lpwr_xtt_motif -lpwr_ge_motif -lpwr_cow_motif -lpwr_flow_motif -lpwr_glow_motif\"" >> $cfile
  echo "export pwre_conf_libpwrwb=\"-lpwr_wb\"" >> $cfile
  echo "export pwre_conf_libpwrwbgtk=\"-lpwr_wb_gtk\"" >> $cfile
  echo "export pwre_conf_libpwrwbmotif=\"-lpwr_wb_motif\"" >> $cfile
  echo "export pwre_conf_libpwropc=\"-lpwr_opc\"" >> $cfile
  echo "export pwre_conf_libpwrremote=\"-lpwr_remote\"" >> $cfile
  echo "export pwre_conf_libpwrnmps=\"-lpwr_nmps\"" >> $cfile
  echo "export pwre_conf_libpwrtlog=\"-lpwr_tlog\"" >> $cfile
  echo "export pwre_conf_libpwrsev=\"-lpwr_sev\"" >> $cfile
  echo "export pwre_conf_lib=\"-lpthread -lm -lrt -lcrypt\"" >> $cfile
  echo "export pwre_conf_libwb=\"$conf_libwb\"" >> $cfile
  echo "export pwre_conf_libmq=\"$conf_libmq\"" >> $cfile
  echo "export pwre_conf_libwmq=\"$conf_libwmq\"" >> $cfile
  echo "export pwre_conf_libgtk=\"$conf_libgtk\"" >> $cfile
  echo "export pwre_conf_libmotif=\"$conf_libmotif\"" >> $cfile
  echo "export pwre_conf_libdir=\"$conf_libdir\"" >> $cfile
  echo "export pwre_conf_incdir=\"$conf_incdir\"" >> $cfile
  echo "export pwre_conf_incdirgtk=\"$conf_incdirgtk\"" >> $cfile
  echo "export pwre_conf_dtt_platform=\"arm_linux\"" >> $cfile
else

  #Gtk
  echo ""
  echo "Mandatory :"
  pwre_config_check_lib gtk    	  GTK      gtk gtk 0 "/usr/lib/libgtk-x11-2.0.dll.a"

  pwre_config_check_lib librpcsvc LIBRPCSVC lib lib 0 "/usr/lib/libtirpc.a"
  pwre_config_check_lib libasound LIBASOUND lib lib 0 "/usr/lib/libasound.so:/usr/lib/libasound.a"
  pwre_config_check_lib libpthread LIBPTHREAD lib lib 0 "/usr/lib/libpthread.so:/usr/lib/libpthread.a:/usr/lib/$hwpl-linux-gnu/libpthread.so"
  pwre_config_check_lib libm      LIBM     lib lib 0 "/usr/lib/libm.so:/usr/lib/libm.a:/usr/lib/$hwpl-linux-gnu/libm.so"
  pwre_config_check_lib libdb     LIBDB    lib lib 0 "/usr/lib/libdb.a"
  pwre_config_check_lib libdb_cxx LIBDB_CXX lib wb 0 "/usr/lib/libdb_cxx.a"
  pwre_config_check_lib libz      LIBZ     lib lib 0 "/usr/lib/libz.dll.a:/usr/lib/libz.a"
  pwre_config_check_lib libcrypt  LIBCRYPT lib lib 0 "/usr/lib/libcrypt.dll.a:/usr/lib/libcrypt.a"
  pwre_config_check_lib librt     LIBRT    lib lib 0 "/usr/lib/librt.dll.a:/usr/lib/librt.a"
  pwre_config_check_lib libfl     LIBFL    lib lib 0 "/usr/lib/libfl.so:/usr/lib/libfl.a"
  pwre_config_check_lib libiconv  LIBICONV lib lib 0 "/usr/lib/libiconv.dll.a:/usr/lib/libiconv.a"
  pwre_config_check_lib libX11    LIBX11   lib lib 0 "/usr/lib/libX11.a"

  pwre_config_check_include gtk   GTK   1 "/usr/local/include/gtk-2.0/gtk.h:/usr/local/include/gtk-2.0/gtk/gtk.h:/usr/include/gtk-2.0/gtk"
  pwre_config_check_include jni   JNI   1 "$jdk/include/jni.h"
  pwre_config_check_include jni   JNI   0 "$jdk/include/win32/jni_md.h"
  pwre_config_check_include alsa  ALSA  1 "/usr/include/alsa/asoundlib.h"
  pwre_config_check_include rpc   RPC  1 "/usr/include/tirpc/rpc"

  echo ""
  echo "Optional :"
  pwre_config_check_lib motif     MRM      motif motif 0 "/usr/lib/libMrm.so"
  pwre_config_check_lib mysql     MYSQL    lib lib 1 "/usr/lib/libmysqlclient.so:/usr/lib/mysql/libmysqlclient.so"
  pwre_config_check_lib mq        MQ       lib mq  1 "/usr/lib/libdmq.so:/usr/local/dmq/lib/libdmq.so"
  pwre_config_check_lib wmq       WMQ      lib wmq 1 "/usr/lib/libmqic.so"
  pwre_config_check_lib libpnioif PNAK     lib lib 1 "/usr/lib/libpnioif.a:/usr/local/lib/libpnioif.a"
  pwre_config_check_lib libusb    LIBUSB   lib libusb 1 "/usr/lib/libusb-1.0.a"

  pwre_config_check_include mq    MQ    0 "/usr/local/dmq/include/p_entry.h"
  pwre_config_check_include wmq   WMQ   1 "/opt/mqm/inc/cmqc.h"
  pwre_config_check_include cifx  CIFX  1 "/usr/local/include/cifx/cifxlinux.h"


  export pwre_conf_alsa=1


  let i=0
  while [ $i -lt $inc_cnt ]; do
      conf_incdir=$conf_incdir" -I${inc_array[$i]}"
      i=$((i+1))
  done

  let i=0
  while [ $i -lt $lib_cnt ]; do
      conf_libdir=$conf_libdir" -L${lib_array[$i]}"
      i=$((i+1))
  done


  echo "export pwre_conf_cc_define=\"$conf_cc_define\"" >> $cfile
  echo "export pwre_conf_libpwrco=\"-lpwr_co\"" >> $cfile
  echo "export pwre_conf_libpwrrt=\"-lpwr_rt -lpwr_statussrv -lpwr_co -lpwr_msg_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrdtt=\"-lpwr_dtt\"" >> $cfile
  echo "export pwre_conf_libpwrotherio=\"-lpwr_usbio_dummy -lpwr_usb_dummy -lpwr_cifx_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrprofibus=\"-lpwr_pnak_dummy\"" >> $cfile
  echo "export pwre_conf_libpwrxtt=\"-lpwr_xtt -lpwr_ge -lpwr_cow -lpwr_flow -lpwr_glow\"" >> $cfile
  echo "export pwre_conf_libpwrxttgtk=\" -lpwr_xtt_gtk -lpwr_ge_gtk -lpwr_cow_gtk -lpwr_flow_gtk -lpwr_glow_gtk\"" >> $cfile
  echo "export pwre_conf_libpwrxttmotif=\" -lpwr_xtt_motif -lpwr_ge_motif -lpwr_cow_motif -lpwr_flow_motif -lpwr_glow_motif\"" >> $cfile
  echo "export pwre_conf_libpwrwb=\"-lpwr_wb\"" >> $cfile
  echo "export pwre_conf_libpwrwbgtk=\"-lpwr_wb_gtk\"" >> $cfile
  echo "export pwre_conf_libpwrwbmotif=\"-lpwr_wb_motif\"" >> $cfile
  echo "export pwre_conf_libpwropc=\"-lpwr_opc\"" >> $cfile
  echo "export pwre_conf_libpwrremote=\"-lpwr_remote\"" >> $cfile
  echo "export pwre_conf_libpwrnmps=\"-lpwr_nmps\"" >> $cfile
  echo "export pwre_conf_libpwrtlog=\"-lpwr_tlog\"" >> $cfile
  echo "export pwre_conf_libpwrsev=\"-lpwr_sev\"" >> $cfile
  echo "export pwre_conf_lib=\"$conf_lib\"" >> $cfile
  echo "export pwre_conf_libwb=\"$conf_libwb\"" >> $cfile
  echo "export pwre_conf_libmq=\"$conf_libmq\"" >> $cfile
  echo "export pwre_conf_libwmq=\"$conf_libwmq\"" >> $cfile
  echo "export pwre_conf_libgtk=\"$conf_libgtk\"" >> $cfile
  echo "export pwre_conf_libmotif=\"$conf_libmotif\"" >> $cfile
  echo "export pwre_conf_libdir=\"$conf_libdir\"" >> $cfile
  echo "export pwre_conf_incdir=\"$conf_incdir\"" >> $cfile
  echo "export pwre_conf_incdirgtk=\"$conf_incdirgtk\"" >> $cfile

fi
